==> react-rotator-0.1.2.tgz: package/es/index.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cleanProps from 'clean-react-props';

var Rotator = function (_Component) {
  _inherits(Rotator, _Component);

  function Rotator(props) {
    _classCallCheck(this, Rotator);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {
      index: props.index
    };

    _this.onIndicatorChange = _this.onIndicatorChange.bind(_this);
    _this.onItemActive = _this.onItemActive.bind(_this);
    _this.onItemFinish = _this.onItemFinish.bind(_this);
    return _this;
  }

  Rotator.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var index = nextProps.index;


    if (index !== this.props.index) {
      this.setState({
        index: index
      });
    }
  };

  Rotator.prototype.onIndicatorChange = function onIndicatorChange(index) {
    var onChange = this.props.onChange;


    this.setState({
      index: index
    });

    onChange({
      index: index
    });
  };

  Rotator.prototype.onItemActive = function onItemActive(index) {
    var onChange = this.props.onChange;


    this.setState({
      index: index
    });

    onChange({
      index: index
    });
  };

  Rotator.prototype.onItemFinish = function onItemFinish() {
    var _props = this.props,
        children = _props.children,
        onChange = _props.onChange;
    var index = this.state.index;


    var nextIndex = index + 1;
    if (nextIndex === React.Children.count(children)) {
      nextIndex = 0;
    }

    this.setState({
      index: nextIndex
    });

    onChange({
      index: nextIndex
    });
  };

  Rotator.prototype.render = function render() {
    var _this2 = this;

    var _props2 = this.props,
        children = _props2.children,
        indicator = _props2.indicator;
    var index = this.state.index;


    var clonedChildren = React.Children.toArray(children).map(function (child, childIndex) {
      return React.cloneElement(child, {
        index: childIndex,
        position: (index - childIndex) * -1,
        onActive: _this2.onItemActive,
        onFinish: _this2.onItemFinish
      });
    });

    var clonedIndicator = indicator ? React.cloneElement(indicator, {
      index: index,
      length: children.length,
      onChange: this.onIndicatorChange
    }) : null;

    return React.createElement(
      'div',
      cleanProps(this.props),
      clonedChildren,
      clonedIndicator
    );
  };

  return Rotator;
}(Component);

Rotator.propTypes = {
  index: PropTypes.number,
  indicator: PropTypes.element,
  onChange: PropTypes.func
};

Rotator.defaultProps = {
  index: 0,
  onChange: function onChange() {}
};

export default Rotator;

==> react-rotator-0.2.0.tgz: package/es/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cleanProps from 'clean-react-props';

var Rotator = function (_Component) {
  _inherits(Rotator, _Component);

  function Rotator(props) {
    _classCallCheck(this, Rotator);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {
      index: props.index
    };

    _this.onIndicatorChange = _this.onIndicatorChange.bind(_this);
    _this.onItemActive = _this.onItemActive.bind(_this);
    _this.onItemFinish = _this.onItemFinish.bind(_this);
    return _this;
  }

  Rotator.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var index = nextProps.index;


    if (index !== this.props.index) {
      this.setState({
        index: index
      });
    }
  };

  Rotator.prototype.onIndicatorChange = function onIndicatorChange(index) {
    var onChange = this.props.onChange;


    this.setState({
      index: index
    });

    onChange({
      index: index
    });
  };

  Rotator.prototype.onItemActive = function onItemActive(index) {
    var onChange = this.props.onChange;


    this.setState({
      index: index
    });

    onChange({
      index: index
    });
  };

  Rotator.prototype.onItemFinish = function onItemFinish() {
    var _props = this.props,
        children = _props.children,
        onChange = _props.onChange;
    var index = this.state.index;


    var nextIndex = index + 1;
    if (nextIndex === React.Children.count(children)) {
      nextIndex = 0;
    }

    this.setState({
      index: nextIndex
    });

    onChange({
      index: nextIndex
    });
  };

  Rotator.prototype.render = function render() {
    var _this2 = this;

    var _props2 = this.props,
        children = _props2.children,
        component = _props2.component,
        indicator = _props2.indicator;
    var index = this.state.index;


    var clonedChildren = React.Children.toArray(children).map(function (child, childIndex) {
      return React.cloneElement(child, {
        index: childIndex,
        position: (index - childIndex) * -1,
        onActive: _this2.onItemActive,
        onFinish: _this2.onItemFinish
      });
    });

    var clonedIndicator = indicator ? React.cloneElement(indicator, {
      index: index,
      length: children.length,
      onChange: this.onIndicatorChange
    }) : null;

    return React.createElement(component, _extends({}, cleanProps(this.props)), [].concat(clonedChildren, [clonedIndicator]));
  };

  return Rotator;
}(Component);

Rotator.propTypes = {
  component: PropTypes.oneOfType([PropTypes.element, PropTypes.string]),
  index: PropTypes.number,
  indicator: PropTypes.element,
  onChange: PropTypes.func
};

Rotator.defaultProps = {
  component: 'div',
  index: 0,
  onChange: function onChange() {}
};

export default Rotator;
